import React from 'react';
import ReactDOM from 'react-dom';
import {
  scaleBand,
  scaleLinear,
  max,
  format,
  scaleOrdinal,
} from 'd3';

import { useData } from './useData';

import { CategoriesChart } from './CategoriesChart';
import { AxisBottom } from './AxisBottom';
import { Title } from './Title';

const width = 960;
const height = 500;
const margin = {
  top: 60,
  right: 290,
  bottom: 20,
  left: 190,
};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;
const xLabelOffset = 25;
const xTitleOffset = 50;
const yLabelOffset = 10;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre></pre>;
  }

  const titleText =
    'Psychische Belastung Geflüchteter in Österreich';

  const gValue = (d) => d.Überkategorie;
  const xValue = (d) =>
    d.mittelgradig_bis_schwere_Belastung;
  const xValueLabel = 'Mittelgradig bis schwere Belastung';
  const yValue = (d) => d.Kategorie;
  const xValue1 = (d) => d.keine_Belastung;
  const xValueLabel1 = 'Keine Belastung';

  const gScale = scaleBand()
    .domain(data.map(gValue))
    .range([0, innerHeight])
    .paddingInner(0.1)
    .paddingOuter(0);

  const xScale = scaleLinear()
    .domain([0, 90])
    .range([0, innerWidth]);

  const xScale1 = scaleLinear()
    .domain([0, 90])
    .range([0, innerWidth]);

  return (
    <div className="App">
      <svg width={width} height={height}>
        <g
          transform={`translate(${margin.left}, ${margin.top})`}
        >
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            xLabelOffset={xLabelOffset}
            xTitleOffset={xTitleOffset}
          />

          {gScale.domain().map((cont) => {
            const yScale = scaleBand()
              .domain(
                data
                  .filter((d) => d.Überkategorie === cont)
                  .map(yValue)
              )
              .range([0, gScale.bandwidth()])
              .padding(0.1);

            console.log(cont);

            const gHeight = gScale.bandwidth();

            return (
              <>
                <Title
                  titleText={titleText}
                  titleOffset={0}
                />
                <CategoriesChart
                  data={data.filter(
                    (d) => d.Überkategorie === cont
                  )}
                  xScale={xScale}
                  xValue={xValue}
                  yScale={yScale}
                  yValue={yValue}
                  xScale1={xScale1}
                  xValue1={xValue1}
                  yLabelOffset={yLabelOffset}
                  innerWidth={innerWidth}
                  innerHeight={gHeight}
                  y={gScale(cont)}
                  title={cont}
                />
                <circle
                  fill={'#31152B'}
                  cx={495}
                  cy={15}
                  r={5}
                />
                <text
                  className="legend-text"
                  x={505}
                  y={20}
                >
                  {xValueLabel}
                </text>
                <circle
                  fill={'#D4636F'}
                  cx={495}
                  cy={35}
                  r={5}
                />
                <text
                  className="legend-text"
                  x={505}
                  y={40}
                >
                  {xValueLabel1}
                </text>
              </>
            );
          })}
        </g>
      </svg>
    </div>
  );
};

ReactDOM.render(<App />, document.getElementById('root